changeset 750:d75f7a3cfe3e draft

New tests added into BitBltUsingBgColor.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 12 Aug 2015 11:01:53 +0200
parents ee70173c9080
children a55ded659895
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 65 insertions(+), 60 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Aug 11 10:27:15 2015 +0200
+++ b/ChangeLog	Wed Aug 12 11:01:53 2015 +0200
@@ -1,3 +1,8 @@
+2015-08-11  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	New tests added into BitBltUsingBgColor.
+
 2015-08-11  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Aug 11 10:27:15 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Aug 12 11:01:53 2015 +0200
@@ -9871,7 +9871,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -9880,13 +9880,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -9895,13 +9895,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -9910,13 +9910,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -9925,13 +9925,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9940,13 +9940,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9955,13 +9955,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9970,13 +9970,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9985,13 +9985,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -10000,9 +10000,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.blue);
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.blue);
     }
 
     /**
@@ -9871,7 +9871,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.blue.
      *